# Generated by Django 5.1.6 on 2025-05-02 14:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('history4feed', '0004_alter_fulltextjob_status_alter_job_state'),
    ]

    operations = [
        migrations.AddField(
            model_name='feed',
            name='datetime_modified',
            field=models.DateTimeField(default=None, help_text='date feed entry was edited in the database', null=True),
        ),
    ]
